Package: rWikiPathways
Type: Package
Title: rWikiPathways - R client library for the WikiPathways API
Version: 1.32.0
Date: 2025-10-14
Authors@R: c(person("Egon", "Willighagen", role = c("aut","cre"),
                     email = "egon.willighagen@gmail.com",
                     comment = c(ORCID = "0000-0001-7542-0286")),
             person("Alex", "Pico", role = "aut",
                     email = "alex.pico@gladstone.ucsf.edu",
                     comment = c(ORCID = "0000-0001-5706-2163"))
           )
Imports: httr, utils, XML, rjson, data.table, RCurl, dplyr, tidyr,
        readr, stringr, purrr, lubridate
Suggests: testthat, BiocStyle, knitr, rmarkdown
Encoding: UTF-8
Description: Use this package to interface with the WikiPathways API. It provides programmatic access to WikiPathways content in multiple data and image formats, including official monthly release files and convenient GMT read/write functions.
License: MIT + file LICENSE
URL: https://github.com/wikipathways/rWikiPathways
BugReports: https://github.com/wikipathways/rWikiPathways/issues
LazyLoad: yes
biocViews: Visualization, GraphAndNetwork, ThirdPartyClient, Network,
        Metabolomics
NeedsCompilation: no
VignetteBuilder: knitr
RoxygenNote: 7.2.3
git_url: https://git.bioconductor.org/packages/rWikiPathways
git_branch: RELEASE_3_23
git_last_commit: e7c3210
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-29 00:21:42 UTC; biocbuild
Author: Egon Willighagen [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-7542-0286>),
  Alex Pico [aut] (ORCID: <https://orcid.org/0000-0001-5706-2163>)
Maintainer: Egon Willighagen <egon.willighagen@gmail.com>

# Generated by roxygen2: do not edit by hand

export(downloadPathwayArchive)
export(findPathwayIDsByOrcid)
export(findPathwayIdsByLiterature)
export(findPathwayIdsByText)
export(findPathwayIdsByXref)
export(findPathwayNamesByLiterature)
export(findPathwayNamesByOrcid)
export(findPathwayNamesByText)
export(findPathwayNamesByXref)
export(findPathwayUrlsByLiterature)
export(findPathwayUrlsByOrcid)
export(findPathwayUrlsByText)
export(findPathwayUrlsByXref)
export(findPathwaysByLiterature)
export(findPathwaysByOrcid)
export(findPathwaysByText)
export(findPathwaysByXref)
export(getCounts)
export(getCurationStatus)
export(getCurationTagNames)
export(getCurationTags)
export(getEveryCurationTag)
export(getOntologyTermIds)
export(getOntologyTermNames)
export(getOntologyTerms)
export(getPathway)
export(getPathwayHistory)
export(getPathwayIdsByCommunity)
export(getPathwayIdsByCurationTag)
export(getPathwayIdsByOntologyTerm)
export(getPathwayIdsByParentOntologyTerm)
export(getPathwayInfo)
export(getPathwayNamesByCommunity)
export(getPathwayUrlsByCommunity)
export(getPathwaysByCommunity)
export(getPathwaysByCurationTag)
export(getPathwaysByOntologyTerm)
export(getPathwaysByParentOntologyTerm)
export(getRecentChanges)
export(getRecentChangesIds)
export(getRecentChangesNames)
export(getXrefList)
export(listCommunities)
export(listOrganisms)
export(listPathwayIds)
export(listPathwayNames)
export(listPathwayUrls)
export(listPathways)
export(readGMT)
export(readGMTnames)
export(readPathwayGMT)
export(wikipathwaysAPI)
export(wikipathwaysGET)
export(writeGMT)
import(dplyr)
importFrom(RCurl,getURL)
importFrom(XML,readHTMLTable)
importFrom(data.table,rbindlist)
importFrom(httr,GET)
importFrom(purrr,map_dfr)
importFrom(rjson,fromJSON)
importFrom(tidyr,separate)
importFrom(utils,URLencode)
importFrom(utils,browseURL)
importFrom(utils,download.file)
importFrom(utils,stack)
importFrom(utils,write.table)

# R Client Package for WikiPathways
[![BioC Release Build Status](http://bioconductor.org/shields/build/release/bioc/rWikiPathways.svg)](http://bioconductor.org/checkResults/release/bioc-LATEST/rWikiPathways/) - Bioconductor Release Build

[![BioC Dev Build Status](http://bioconductor.org/shields/build/devel/bioc/rWikiPathways.svg)](http://bioconductor.org/checkResults/devel/bioc-LATEST/rWikiPathways/) - Bioconductor Dev Build

R Client library for the WikiPathways API (https://webservice.wikipathways.org/) (license: MIT).

WikiPathays is described in the following papers:
* 2016 NAR paper by [Kutmon et al.](https://doi.org/10.1093/nar/gkv1024)
* 2018 NAR paper by [Slenter et al.](https://doi.or/10.1093/nar/gkx1064)
* 2021 NAR paper by [Martens et al.](https://doi.org/10.1093/nar/gkaa1024)
* 2024 NAR paper by [Agrawal et al.](https://doi.org/10.1093/nar/gkad960)

If you like this package, or want to make it easier to work with Xrefs, then
you may also like these R packages:

* [BridgeDbR](https://doi.org/10.18129/B9.bioc.BridgeDbR)
* [RCy3](https://doi.org/10.18129/B9.bioc.RCy3)

## Getting Started
* [Documentation site](https://r.wikipathways.org)
* [Overview vignette](https://bioconductor.org/packages/release/bioc/vignettes/rWikiPathways/inst/doc/Overview.html)

## How to install
**_Official bioconductor releases_ (recommended)**
```
if (!requireNamespace("BiocManager", quietly=TRUE))
    install.packages("BiocManager")
BiocManager::install("rWikiPathways")
```
*Note: Be sure to use the [latest Bioconductor](https://www.bioconductor.org/install/) and recommended R version* 

**_Unstable development code from this repo_ (at your own risk)**
```
install.packages("devtools")
library(devtools)
install_github('wikipathways/rWikiPathways', build_vignettes=TRUE)
library(rWikiPathways)
```
#### Troubleshooting
1. If you see this error on a Mac: ```make: gfortran-4.8: No such file or directory```, then try reinstalling R via [homebrew](https://brew.sh/): ```brew update && brew reinstall r```
   * warning: this make take ~30 minutes

## How to contribute
This is a public, open source project. Come on in! You can contribute at multiple levels:

* Report an issue or feature request
* Fork and make pull requests
* Contact current WikiPathways developers and inquire about joining the team

### Development
```
install.packages("devtools")
install.packages("roxygen2") 
library(devtools,roxygen2)
devtools::install_github("AlexanderPico/docthis")
library(docthis)
setwd("/git/wikipathways/rWikiPathways") #customize to your setup
devtools::document()
devtools::check(vignettes = F)
BiocCheck::BiocCheck('./')
```

### Testing
Unit tests are a crucial tool in software development. Be sure to [add tests](tests/testthat) for any new methods implemented. These will be run as part of the `devtools::check()`. 

### Updating site
We use [pkgdown](https://pkgdown.r-lib.org/) to generate the [main site for rWikiPathways](https://wikipathways.github.io/rWikiPathways/index.html) based on this README, metadata, man pages and vignettes. If you make changes to any of these, please take a moment to regenerate the site:
```
library(pkgdown)
pkgdown::build_site()
```

### Bioconductor
While this is the primary development repository for the rWikiPathways project, we also make regular pushes to official bioconductor repository ([devel](http://bioconductor.org/packages/devel/bioc/html/rWikiPathways.html) & [release](http://bioconductor.org/packages/release/bioc/html/rWikiPathways.html)) from which the official releases are generated. This is the correct repo for all coding and bug reporting interests. The tagged releases here correspond to the bioconductor releases via a manual syncing process. The `devel` branch here corresponds to the latest code in development and not yet released. 

```
git commit -m "informative commit message"
git push origin devel
git push upstream devel
```
http://bioconductor.org/developers/how-to/git/push-to-github-bioc/

Following each bioconductor release, a `RELEASE_#_#` branch is created. The new branch is fetched and devel is updated:

```
git fetch upstream
git checkout -b RELEASE_3_15 upstream/RELEASE_3_15
git push origin RELEASE_3_15
git checkout devel
git pull upstream devel
git push origin devel
```

Only bug fixes and documentation updates can be pushed to the official bioconductor release branch. After committing and pushing fixes to `devel`, then:

```
git checkout RELEASE_3_15
git cherry-pick devel #for lastest commit
# or git cherry-pick 1abc234 #for specific commit
# or git cherry-pick 1abc234^..5def678 #for an inclusive range
# bump release version in DESCRIPTION
git commit -am 'version bump'
git push origin RELEASE_3_15
# double check changes, and then...
git push upstream RELEASE_3_15
git checkout devel
# bump dev version in DESCRIPTION
git commit -am 'version bump'
git push origin devel
git push upstream devel
```

And then finally, bump version and commit DESCRIPTION to `devel` and push to origin and upstream.

https://bioconductor.org/developers/how-to/git/bug-fix-in-release-and-devel/

### Vignettes
When adding or updating vignettes, consider the following tips for consistency:
* Copy/paste the header from an existing rWikiPathways vignette, including the global knitr options
* Number the *VignetteIndexEntry* names w.r.t. other vignettes (this determines their presentation order)
* Avoid spaces in Rmd filenames; causes CHECK errors
* When ready, run **Knit to html_vignette_** and review the generated html
* Note: you don't need to save the html version; it will be generated anew at Bioconductor.
* In the end, you should just have an Rmd version of each vignette in the repo.

# ------------------------------------------------------------------------------
#' @title Find Pathways By Literature
#'
#' @description Retrieve pathways containing the query citation.
#' @param query The \code{character} string to search for, e.g., a PMID, title 
#' keyword, journal abbreviation, year, or author name.
#' @return A \code{dataframe} of pathway attributes including the matching
#' citations
#' @examples {
#' findPathwaysByLiterature('15134803')
#' findPathwaysByLiterature('Schwartz GL')
#' findPathwaysByLiterature('Eur J Pharmacol')
#' findPathwaysByLiterature('antihypertensive drug responses')
#' }
#' @export
#' @importFrom purrr map_dfr
findPathwaysByLiterature <- function(query=NULL) {
    if(is.null(query))
        stop("Must provide a query, e.g., 15134803 or Schwartz GL")
    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/findPathwaysByLiterature.json")
    res.df <- res$pathwayInfo %>%
        purrr::map_dfr(~as.data.frame(t(unlist(.x)))) 

    res.df <- res.df %>%
        rowwise() %>%
        dplyr::filter(any(grepl(tolower(query),tolower(c_across(refs:citations)))))

    if(nrow(res.df) == 0)
        message("No results")
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Find Pathway WPIDs By Literature 
#'
#' @description Retrieve list of pathway WPIDs containing the query citation.
#' @param query The \code{character} string to search for, e.g., a PMID, title 
#' keyword or author name.
#' @return A \code{list} of WPIDs
#' @examples {
#' findPathwayIdsByLiterature('19649250')
#' findPathwayIdsByLiterature('smith')
#' findPathwayIdsByLiterature('cancer')
#' }
#' @seealso findPathwaysByLiterature
#' @export 
findPathwayIdsByLiterature <- function(query=NULL) {
    res <- findPathwaysByLiterature(query)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway Names By Literature 
#'
#' @description Retrieve list of pathway names containing the query citation.
#' @param query The \code{character} string to search for, e.g., a PMID, title 
#' keyword or author name.
#' @return A \code{list} of lists
#' @examples {
#' findPathwayNamesByLiterature('19649250')
#' findPathwayNamesByLiterature('smith')
#' findPathwayNamesByLiterature('cancer')
#' }
#' @seealso findPathwaysByLiterature
#' @export 
findPathwayNamesByLiterature <- function(query=NULL) {
    res <- findPathwaysByLiterature(query)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway URLs By Literature 
#'
#' @description Retrieve list of pathway URLs containing the query citation.
#' @param query The \code{character} string to search for, e.g., a PMID, title 
#' keyword or author name.
#' @return A \code{list} of lists
#' @examples {
#' findPathwayUrlsByLiterature('19649250')
#' findPathwayUrlsByLiterature('smith')
#' findPathwayUrlsByLiterature('cancer')
#' }
#' @seealso findPathwaysByLiterature
#' @export 
findPathwayUrlsByLiterature <- function(query=NULL) {
    res <- findPathwaysByLiterature(query)
    return(res$url)
}

library(rWikiPathways)
context("Search")

test_that("find by keyword", {
    pathways = findPathwaysByLiterature("cancer")
    expect_gt(length(pathways), 0)
})

test_that("find by pmid (again)", {
    pathways = findPathwaysByLiterature(query="10423528")
    expect_gt(length(pathways), 0)
})

test_that("find by author", {
    pathways = findPathwaysByLiterature(query="smith")
    expect_gt(length(pathways), 0)
})

# ------------------------------------------------------------------------------
#' @title Write GMT File
#'
#' @description Writes a GMT (Gene Matrix Transposed) file from a data frame.
#' @param df Data frame with columns ordered as Identifiers, optional 
#' Description column and Genes. Identifiers must be first and Genes must be 
#' last.
#' @param outfile Path to output GMT file 
#' @return None
#' @details The input data frame must include at least two columns: Identifiers
#' (first column) and Genes (last column). The Identifiers will be duplicated to
#' fill the Description column in the output GMT file if none is provided. If 
#' more than three columns are provided, then the first n columns will be 
#' concatenated with % separators to form the ID, where n+2 equals the total
#' number of columns.
#' @references Adapted from the GMT writer in MAGeCKFlute,
#'  \url{https://github.com/WubingZhang/MAGeCKFlute/blob/master/R/readGMT.R}
#' @examples \donttest{
#' #my.df <- data.frame(id=c("WP1000","WP1000","WP1000","WP1001","WP1001"),
#' #         description=c("cancer","cancer","cancer","diabetes","diabetes"),
#' #         gene=c("574413","2167","4690","5781","11184"))
#' #writeGMT(my.df, "my_gmt_file.gmt")
#' }
#' @seealso readPathwayGMT
#' @importFrom utils write.table
#' @export
writeGMT <- function(df, outfile){
    
    # Assess and prep data frame
    df.len <- length(df)
    if(df.len < 2){
        stop("The input data frame must include at least two columns.")
    } else if(df.len == 2){
        df$desc <- df[,1]
        df <- df[,c(1,3,2)]
    } else if(df.len > 3){
        id.cols <- names(df[,seq(1,df.len-2)])
        message(paste0("Concatenating the following columns to use as Identifiers: ",paste(id.cols, collapse = ", ")))
        df[,df.len+1] <- apply(df[,id.cols],1,paste,collapse="%")
        df <- df[,!(names(df) %in% id.cols)]
        df <- df[,c(3,1,2)]
    }
    
    # Generate file
    genelists = lapply(unique(df[,1]), function(x){
        paste(df[df[,1]==x, 3], collapse = "\t")
        })
    gmt = cbind(unique(df[,1]), df[!duplicated(df[,1]),2], unlist(genelists))
    write.table(gmt, outfile, sep = "\t", row.names = FALSE,
                col.names = FALSE, quote = FALSE)
}

# ------------------------------------------------------------------------------
#' @title Get Xref List
#'
#' @description Retrieve the Xref identifiers for a specific pathway in a 
#' particular system code
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, 
#' e.g. WP554
#' @param systemCode (\code{character}) The BridgeDb code associated with the 
#' data source or system, 
#' e.g., En (Ensembl), L (NCBI gene), H (HGNC), S (UniProt), Wd (Wikidata), 
#' Ce (ChEBI), Ik (InChI). See column two of 
#' https://github.com/bridgedb/datasources/blob/main/datasources.tsv.
#' @param compact (\code{Boolean}) Whether to return compact identifiers, like
#' ncbigene:1215. If FALSE (default), then just the identifier is returned, like
#'  1215
#' @return A \code{list} of Xrefs identifiers
#' @examples {
#' xrefs = getXrefList("WP2338", "L")
#' }
#' @export
getXrefList <- function(pathway=NULL, systemCode=NULL, compact=FALSE) {
    if(is.null(pathway))
        stop("Must provide a pathway identifier, e.g., WP554")
    if(is.null(systemCode))
        stop("Must provide a systemCode, e.g., L")
    
    code.list <- c(
        "En"="Ensembl",
        "L"="NCBI gene",
        "H"= "HGNC",
        "S"="UniProt",
        "Wd"= "Wikidata", 
        "Ce"= "ChEBI", 
        "Ik"= "InChI"
    )
    
    if(!systemCode %in% names(code.list))
        stop("Must provide a supported systemCode, e.g., L (see docs)")
    
    res <- readr::read_tsv(paste0("https://www.wikipathways.org/wikipathways-assets/pathways/",
                           pathway,"/",
                           pathway,"-datanodes.tsv"),
                    show_col_types = FALSE)
    
    res.list <- res %>%
        dplyr::select(code.list[[systemCode]]) %>%
        tidyr::drop_na() %>%
        tidyr::separate_rows(code.list[[systemCode]], sep=";") %>%
        as.list() %>%
        unname() %>%
        unlist() %>%
        unique()
    
    if(!compact)
        res.list <- stringr::str_replace(res.list, ".*:", "")
    
    return(res.list)
}

library(rWikiPathways)
context("Pathway")

test_that("get WP2338 Xrefs", {
  xrefs = getXrefList("WP2338", "S")
  expect_true("Q9UPY3" %in% xrefs)
})

test_that("get WP2338 (again)", {
  xrefs = getXrefList(pathway="WP2338", systemCode="S")
  expect_true("Q9UPY3" %in% xrefs)
})

# ------------------------------------------------------------------------------
#' @title Get Pathway
#'
#' @description Retrieve a specific pathway in the GPML format
#' @param pathway WikiPathways identifier (WPID) for the pathway to retrieve, 
#' e.g. WP554
#' @param revision <ignored> Only the latest version is available.
#' @return GPML as string
#' @examples {
#' getPathway('WP554')
#' }
#' @export
getPathway <- function(pathway, revision=0) {
    if(is.null(pathway))
        stop("Must provide a pathway identifier, e.g., WP554")
    
    res <- httr::GET(paste0("https://www.wikipathways.org/wikipathways-assets/pathways/",
                            pathway,"/",
                            pathway,".gpml"))
    xml_text <- httr::content(res, as="text", encoding = "UTF-8")
    xml_obj <- XML::xmlParse(xml_text)
    xml_string <- XML::saveXML(xml_obj)
    xml_string <- sub("\n*$", "", xml_string)
    return(xml_string)
}

library(rWikiPathways)
context("Pathway")

test_that("get WP4", {
  gpml = getPathway("WP4")
  expect_length(gpml, 1)
})

test_that("get WP4 (again)", {
  gpml = getPathway(pathway="WP4")
  expect_length(gpml, 1)
})

test_that("get a specific revision of WP4", {
  gpml = getPathway(pathway="WP4", revision=83654)
  expect_length(gpml, 1)
})

# ------------------------------------------------------------------------------
#' @title Find Pathways By Text
#'
#' @description Retrieve pathways matching the query text.
#' @param query A \code{character} string to search for, e.g., "cancer". Case 
#' insensitive.
#' @param field Optional \code{character} string to restrict search to a single
#' field, e.g., id, name, description, species, revision, authors,
#' datanodes, annotations, or citedIn.
#' @return A \code{dataframe} of pathway attributes including the matching
#' attributes
#' @details Searches id, name, description, species, revision date, authors,
#' datanode labels, ontology annotations, and citedIn (e.g., PMCIDs).
#' @examples {
#' findPathwaysByText('cancer')
#' findPathwaysByText('cancer','name')
#' }
#' @export
findPathwaysByText <- function(query=NULL, field=NULL) {
    if(is.null(query))
        stop("Must provide a query, e.g., ACE2")
    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/findPathwaysByText.json")
    res.df <- res$pathwayInfo %>%
        purrr::map_dfr(~as.data.frame(t(unlist(.x)))) 
    
    if(!is.null(field) && !field %in% names(res.df))
        stop("Must provide a supported field, e.g., name")
    
    if(is.null(field)){
        res.df <- res.df %>%
            rowwise() %>%
            dplyr::filter(any(grepl(tolower(query),tolower(c_across(id:citedIn)))))
    } else {
        res.df <- res.df %>%
            dplyr::filter(grepl(tolower(query),tolower(res.df[[field]])))
    }
    
    if(nrow(res.df) == 0)
        message("No results")
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Find Pathway WPIDs By Text 
#'
#' @description Retrieve list of pathway WPIDs containing the query text.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @param field Optional \code{character} string to restrict search to a single
#' field, e.g., title, description, wpid, species, revision, authors,
#' datanodes, annotations, or citedIn.
#' @return A \code{list} of WPIDs
#' @examples {
#' findPathwayIdsByText('cancer')
#' }
#' @seealso findPathwaysByText
#' @export 
findPathwayIdsByText <- function(query=NULL, field=NULL) {
    res <- findPathwaysByText(query, field)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway Names By Text 
#'
#' @description Retrieve list of pathway names containing the query text.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @param field Optional \code{character} string to restrict search to a single
#' field, e.g., title, description, wpid, species, revision, authors,
#' datanodes, annotations, or citedIn.
#' @return A \code{list} of pathway names
#' @examples {
#' findPathwayNamesByText('cancer')
#' }
#' @seealso findPathwaysByText
#' @export 
findPathwayNamesByText <- function(query=NULL, field=NULL) {
    res <- findPathwaysByText(query,field)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway URLs By Text 
#'
#' @description Retrieve list of pathway URLs containing the query text.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @param field Optional \code{character} string to restrict search to a single
#' field, e.g., title, description, wpid, species, revision, authors,
#' datanodes, annotations, or citedIn.
#' @return A \code{list} of urls
#' @examples {
#' findPathwayUrlsByText('cancer')
#' }
#' @seealso findPathwaysByText
#' @export 
findPathwayUrlsByText <- function(query=NULL, field=NULL) {
    res <- findPathwaysByText(query,field)
    return(res$url)
}

library(rWikiPathways)
context("Search")

test_that("find by keyword", {
    pathways = findPathwaysByText("cancer")
    expect_gt(length(pathways),0)
})

test_that("find by datanode label (again)", {
    pathways = findPathwaysByText(query="5-FU")
    expect_gt(length(pathways), 0)
})

test_that("find by multiple keywords", {
    pathways = findPathwaysByText(query=c("cancer", "5-FU"))
    expect_gt(length(pathways), 0)
})

# ------------------------------------------------------------------------------
#' @title Get Pathway Info
#'
#' @description Retrieve information for a specific pathway
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, 
#' e.g. WP554. If NULL, then all pathways are returned.
#' @return A \code{dataframe} of pathway WPID, URL, name, species, revision,
#' authors, description, and citedIn
#' @examples {
#' getPathwayInfo('WP554')
#' }
#' @export
getPathwayInfo <- function(pathway=NULL) {
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/getPathwayInfo.json")
    res.df <- res$pathwayInfo %>%
        purrr::map_dfr(~as.data.frame(t(unlist(.x)))) 
    
    if(!is.null(pathway))
       res.df <- dplyr::filter(res.df, id == pathway)
    
    return(res.df)
}

library(rWikiPathways)
context("Pathway")

test_that("get WP554", {
  info = getPathwayInfo("WP554")
  expect_that(info$id, equals("WP554"))
})

test_that("get WP554 (again)", {
  info = getPathwayInfo(pathway="WP554")
  expect_that(info$id, equals("WP554"))
})

# ------------------------------------------------------------------------------
#' @title Get Curation Status of a Pathway
#'
#' @description Retrieve information about curation status for a specific pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway, e.g. WP554
#' @return A \code{data.frame} of status details
#' @examples {
#' getCurationStatus('WP554')
#' }
#' @export
getCurationStatus <- function(pathway) {
    if(is.null(pathway))
        stop("Must provide a pathway identifier, e.g., WP554")
    
    res<-rjson::fromJSON(
        file=paste0("https://www.wikipathways.org/wikipathways-collection/reports/",pathway,".json"))
    
    return(as.data.frame(res))
}

# ------------------------------------------------------------------------------
#' @title DEPRECATED: Get Curation Tags on a Pathway
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @return A \code{list} of tag name, display name, revision, text, timestampe and user
#' @export
getCurationTags <- function(pathway) {
    .Deprecated("getCurationStatus")
    
    res <- wikipathwaysGET('getCurationTags',list(pwId=pathway))
    return(unname(res$tags))
}

# ------------------------------------------------------------------------------
#' @title DEPRECATED: Get Curation Tag Names on a Pathway
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @return A \code{list} of tag names
#' @export
getCurationTagNames <- function(pathway) {
    .Deprecated("getCurationStatus")
    
    unlist(lapply(getCurationTags(pathway), function(x) {unname(x['name'])}))
}

# ------------------------------------------------------------------------------
#' @title DEPRECATED: Get Every Instance of a Curation Tag
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param tag (\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"
#' @return A \code{list} of tag name, display name, revision, text, timestampe and user
#' @export
getEveryCurationTag <- function(tag) {
    .Deprecated("listCommunities")
    
    res <- wikipathwaysGET('getCurationTagsByName',list(tagName=tag))
    return(unname(res$tags))
}

# ------------------------------------------------------------------------------
#' @title DEPRECATED: Get Pathways by Curation Tag 
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param tag (\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"
#' @return A \code{list} of pathway information, including WPID, url, name, species and revision
#' @export
getPathwaysByCurationTag <- function(tag) {
    .Deprecated("getPathwaysByCommunity")
    
    pathway.list <- lapply(getEveryCurationTag(tag), function(x) {unname(x['pathway'])})
    lapply(pathway.list, unlist)
}

# ------------------------------------------------------------------------------
#' @title DEPRECATED: Get Pathway WPIDs by Curation Tag 
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param tag (\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"
#' @return A \code{list} of pathway WPIDs
#' @export
getPathwayIdsByCurationTag <- function(tag) {
    .Deprecated("getPathwayIdsByCommunity")
    
    p.info.list <- lapply(getEveryCurationTag(tag), function(x) {unname(x['pathway'])})
    p.info <- lapply(p.info.list, unlist)
    unlist(lapply(p.info,function(x) {unname(x['id'])}))
}

library(rWikiPathways)
context("Annotation")

test_that("get by WPID", {
    tags = getCurationTags('WP554')
    expect_gt(length(tags),0)
})

test_that("get by tag name", {
    tags = getEveryCurationTag('Curation:FeaturedPathway')
    expect_gt(length(tags), 0)
})

test_that("find by tag name", {
    pathways = getPathwaysByCurationTag('Curation:FeaturedPathway')
    expect_gt(length(pathways), 0)
})

# ------------------------------------------------------------------------------
#' @title List Organisms
#'
#' @description Retrieve the list of organisms supported by WikiPathways
#' @return A \code{list} of organisms
#' @examples {
#' listOrganisms()
#' }
#' 
#' @export
listOrganisms <- function() {
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/listOrganisms.json")
    res$organisms
}

# ------------------------------------------------------------------------------
#' @title Get Recent Changes
#'
#' @description Retrieve recently changed pathways at WikiPathways.
#' @param timestamp (8 digits, YYYYMMDD) Limit by time, only pathways changed 
#' after the given date, e.g., 20180201 for changes since Feb 1st, 2018.
#' @return A \code{data.frame} of recently changed pathways, including id, name,
#' url, species and revision
#' @examples {
#' getRecentChanges('20180201')
#' }
#' @export
getRecentChanges <- function(timestamp=NULL) {
    if(is.null(timestamp))
        timestamp <- 20070301
    timestamp <- substr(timestamp, start = 1, stop = 8)
    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/getPathwayInfo.json")
    res.df <- res$pathwayInfo %>%
        purrr::map_dfr(~as.data.frame(t(unlist(.x)))) %>%
        dplyr::mutate(revision_ymd = lubridate::ymd(revision)) %>%
        dplyr::filter(revision_ymd > lubridate::ymd(timestamp)) %>%
        dplyr::select(-c(revision_ymd,authors,description,citedIn))
    
    return(res.df)
}

# ------------------------------------------------------------------------------
#' @title Get WPIDs of Recent Changes 
#'
#' @description Retrieve WPIDs of recently changed pathways at WikiPathways.
#' @param timestamp (8 digits, YYYYMMDD) Limit by time, only pathways changed 
#' after the given date, e.g., 20180201 for changes since Feb 1st, 2018.
#' @return A \code{list} of WPIDs
#' @examples {
#' getRecentChangesIds('20180201')
#' }
#' @export 
getRecentChangesIds <- function(timestamp) {
    getRecentChanges(timestamp)[['id']]
}

# ------------------------------------------------------------------------------
#' @title Get Pathway Names of Recent Changes 
#'
#' @description Retrieve names of recently changed pathways at WikiPathways.
#' @param timestamp (8 digits, YYYYMMDD) Limit by time, only pathways changed 
#' after the given date, e.g., 20180201 for changes since Feb 1st, 2018.
#' @return A \code{list} of pathway names. Note: pathway deletions will be listed as blank names.
#' @examples {
#' getRecentChangesNames('20180201')
#' }
#' @export 
getRecentChangesNames <- function(timestamp) {
    getRecentChanges(timestamp)[['name']]
}

# ------------------------------------------------------------------------------
#' @title Get Pathway History
#'
#' @description View the revision history of a pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway, e.g. WP554
#' @param timestamp <ignored>
#' @return Opens the GitHub history for a pathway
#' @examples \donttest{
#' #getPathwayHistory('WP554')
#' }
#' @export
getPathwayHistory <- function(pathway=NULL,timestamp=NULL) {
    if(is.null(pathway))
        stop("Must provide a pathway identifier, e.g., WP554")
    
    browseURL(paste0("https://github.com/wikipathways/wikipathways-database/commits/main/pathways/",pathway))
}

# ------------------------------------------------------------------------------
#' @title Download Pathway Archive
#'
#' @description Access the monthly archives of pathway content from WikiPathways.
#' @details If you do not specify an organism, then an archive file
#' will not be downloaded. Rather, the archive will be opened in a tab in your
#' default browser.
#' @param date (optional) The timestamp for a monthly release (e.g., 20171010) 
#' or "current" (default) for latest release.
#' @param organism (optional) A particular species. See \link{listOrganisms}. 
#' @param format (optional) Either gpml (default), gmt or svg.
#' @param destpath (optional) Destination path for file to be downloaded to.
#' Default is current workding directory.
#' @return Filename of downloaded file or an opened tab in default browser
#' @examples \donttest{
#' #downloadPathwayArchive()  ## open in browser
#' #downloadPathwayArchive(format="gmt")  ## open in browser
#' #downloadPathwayArchive(date="20230710", format="svg")  ## open in browser
#' #downloadPathwayArchive(date="20230710", organism="Mus musculus", format="svg")  ## download file
#' #downloadPathwayArchive(organism="Mus musculus")  ## download file
#' }
#' @seealso readPathwayGMT
#' @export
#' @importFrom utils browseURL download.file
#' @importFrom XML readHTMLTable
#' @importFrom RCurl getURL
downloadPathwayArchive <- function(date='current',organism=NULL, format=c('gpml', 'gmt', 'svg'), destpath='./'){
    #get validated format
    format <- match.arg(format)
    
    #validate date
    if (date != 'current')
        if (!grepl("^\\d{8}$",date))
            stop('The date must be 8 digits (YYYYMMDD) or "current"')
    
    #validate organism
    orgs <- listOrganisms()
    if(!is.null(organism))
        if(!organism %in% orgs)
            stop('The organism must match the list of supported organisms, see listOrganisms()')
    
    #download specific file, or...
    if (!is.null(organism)){
        if (date == 'current'){ #determine filename
            data.url <- getURL(paste0('https://data.wikipathways.org/current/',format), 
                               followlocation=TRUE, .opts=list(useragent="Mozila 5.0"))
            curr.files <- readHTMLTable(data.url)[[1]]$`File Name`
            filename <- grep(sub("\\s","_",organism), curr.files, value=TRUE)
            if (length(filename) == 0)
                stop ('Could not find a file matching your specifications. Try browsing https://data.wikipathways.org.')
        } else { #construct filename
            ext <- ".zip"
            if (format == 'gmt')
                ext <- ".gmt"
            filename <- paste0(paste('wikipathways',date,format,sub("\\s","_",organism),sep="-"), ext)
        }
        url <- paste('https://data.wikipathways.org',date, format, filename, sep="/")
        download.file(url, paste(destpath,filename,sep='/'), 'auto')
        return(filename)
    } else { #...just open browser
        url <- paste('https://data.wikipathways.org', date, format, sep="/")
        if (interactive())
            browseURL(url)
    }
}

# ------------------------------------------------------------------------------
#' @title Find Pathways By Xref
#'
#' @description Retrieve pathways containing the query Xref by identifier
#'  and system code.
#' @param identifier (\code{character}) The official ID specified by a data 
#' source or system
#' @param systemCode (\code{character}) The BridgeDb code associated with the 
#' data source or system, 
#' e.g., En (Ensembl), L (NCBI gene), H (HGNC), U (UniProt), Wd (Wikidata), 
#' Ce (ChEBI), Ik (InChI). See column two of 
#' https://github.com/bridgedb/datasources/blob/main/datasources.tsv.
#' @return A \code{dataframe} of pathway attributes including the matching
#' identifiers
#' @examples {
#' findPathwaysByXref('ENSG00000100031','En')
#' }
#' @export
findPathwaysByXref <- function(identifier=NULL, systemCode=NULL) {
    if(is.null(identifier))
        stop("Must provide an identifier to query, e.g., ENSG00000100031")
    if(is.null(systemCode))
        stop("Must provide a systemCode, e.g., En")
    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/findPathwaysByXref.json")
    res.df <- res$pathwayInfo %>%
        purrr::map_dfr(~as.data.frame(t(unlist(.x)))) 
    
    code.list <- c(
        "En"="ensembl",
        "L"="ncbigene",
        "H"= "hgnc",
        "U"="uniprot",
        "Wd"= "wikidata", 
        "Ce"= "chebi", 
        "Ik"= "inchikey"
    )

    if(systemCode %in% names(code.list)){
        res.df <- res.df %>%
            dplyr::filter(grepl(tolower(identifier),tolower(res.df[[code.list[[systemCode]]]])))
    } else {
        stop("Must provide a supported systemCode, e.g., En")
    }
    
    if(nrow(res.df) == 0)
        message("No results")
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Find Pathway WPIDs By Xref 
#'
#' @description Retrieve list of pathway WPIDs containing the query Xref by 
#' identifier and system code.
#' @param identifier (\code{character}) The official ID specified by a data 
#' source or system
#' @param systemCode (\code{character}) The BridgeDb code associated with the 
#' data source or system, 
#' e.g., En (Ensembl), L (Entrez), Ch (HMDB), etc. See column two of 
#' https://github.com/bridgedb/datasources/blob/main/datasources.tsv.
#' @return A \code{list} of WPIDs
#' @examples {
#' findPathwayIdsByXref('ENSG00000100031','En')
#' }
#' @seealso findPathwaysByXref
#' @export 
findPathwayIdsByXref <- function(identifier=NULL, systemCode=NULL) {
    res <- findPathwaysByXref(identifier, systemCode)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway Names By Xref 
#'
#' @description Retrieve list of pathway names containing the query Xref by 
#' identifier and system code.
#' @param identifier (\code{character}) The official ID specified by a data 
#' source or system
#' @param systemCode (\code{character}) The BridgeDb code associated with the 
#' data source or system, 
#' e.g., En (Ensembl), L (Entrez), Ch (HMDB), etc. See column two of 
#' https://github.com/bridgedb/datasources/blob/main/datasources.tsv.
#' @return A \code{list} of lists
#' @examples {
#' findPathwayNamesByXref('ENSG00000100031','En')
#' }
#' @seealso findPathwaysByXref
#' @export 
findPathwayNamesByXref <- function(identifier=NULL, systemCode=NULL) {
    res <- findPathwaysByXref(identifier, systemCode)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway URLs By Xref 
#'
#' @description Retrieve list of pathway URLs containing the query Xref by 
#' identifier and system code.
#' @param identifier (\code{character}) The official ID specified by a data 
#' source or system
#' @param systemCode (\code{character}) The BridgeDb code associated with the 
#' data source or system, 
#' e.g., En (Ensembl), L (Entrez), Ch (HMDB), etc. See column two of 
#' https://github.com/bridgedb/datasources/blob/main/datasources.tsv.
#' @return A \code{list} of lists
#' @examples {
#' findPathwayUrlsByXref('ENSG00000100031','En')
#' }
#' @seealso findPathwaysByXref
#' @export 
findPathwayUrlsByXref <- function(identifier=NULL, systemCode=NULL) {
    res <- findPathwaysByXref(identifier, systemCode)
    return(res$url)
}

library(rWikiPathways)
context("Search")

test_that("find by Xref", {
  pathways = findPathwaysByXref('ENSG00000232810','En')
  expect_gt(length(pathways), 0)
})

test_that("find by Xref (again)", {
  pathways = findPathwaysByXref(identifier="ENSG00000232810", systemCode="En")
  expect_gt(length(pathways), 0)
})

# ------------------------------------------------------------------------------
#' @title Read GMT File
#'
#' @description Reads any generic GMT file to produce a data frame of 
#' term-gene associations useful in enrichment analyses and other 
#' applications.
#' @param file Path to GMT file 
#' @return Data frame of term-gene associations
#' @details The returned data frame includes only terms and genes. If you want
#' another data frame with terms and names, then see readGMTnames. 
#' @examples \donttest{
#' #readGMT(system.file("extdata","my_gmt_file.gmt", package="rWikiPathways"))
#' #readGMT("path_to_your_gmt_file.gmt")
#' }
#' @seealso readGMTnames
#' @export
#' @importFrom tidyr separate
#' @importFrom utils stack
readGMT <- function(file) {
    x <- readLines(file)
    res <- strsplit(x, "\t")
    names(res) <- vapply(res, function(y) y[1], character(1))
    res <- lapply(res, "[", -c(1:2))
    
    wp2gene <- stack(res)
    wp2gene <- wp2gene[, c("ind", "values")]
    colnames(wp2gene) <- c("term", "gene")
    wp2gene[] <- lapply(wp2gene, as.character) #replace factors for strings
    return(wp2gene)
}

# ------------------------------------------------------------------------------
#' @title Read GMT File for Names
#'
#' @description Reads any generic GMT file to produce a data frame of 
#' term-name associations useful in enrichment analyses and other 
#' applications.
#' @param file Path to GMT file 
#' @return Data frame of term-namee associations
#' @details The returned data frame includes only terms and names. If you want
#' another data frame with terms and genes, then see readGMT. 
#' @examples \donttest{
#' #readGMTnames(system.file("extdata","my_gmt_file.gmt", package="rWikiPathways"))
#' #readGMTnames("path_to_your_gmt_file.gmt")
#' }
#' @seealso readGMT
#' @export
#' @importFrom tidyr separate
#' @importFrom utils stack
readGMTnames <- function(file) {
    x <- readLines(file)
    res <- strsplit(x, "\t")
    names(res) <- vapply(res, function(y) y[1], character(1))
    res <- lapply(res, "[", c(2))
    
    wp2name <- stack(res)
    wp2name <- wp2name[, c("ind", "values")]
    colnames(wp2name) <- c("term", "name")
    wp2name[] <- lapply(wp2name, as.character) #replace factors for strings
    return(wp2name)
}

# ------------------------------------------------------------------------------
#' @title Find Pathways By ORCID
#'
#' @description Retrieve pathways containing the query ORCID
#' @param query The \code{character} ORCID to search for.
#' @return A \code{dataframe} of pathway attributes including the matching
#' ORCIDs
#' @examples {
#' findPathwaysByOrcid(' 0000-0001-9773-4008')
#' }
#' @export
#' @importFrom purrr map_dfr
#' @import dplyr
findPathwaysByOrcid <- function(query=NULL) {
    if(is.null(query))
        stop("Must provide an ORCID, e.g.,  0000-0001-9773-4008")
    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/findPathwaysByOrcid.json")
    res.df <- res$pathwayInfo %>%
        purrr::map_dfr(~as.data.frame(t(unlist(.x)))) 

    res.df <- res.df %>%
        rowwise() %>%
        dplyr::filter(grepl(tolower(query),tolower(orcids)))

    if(nrow(res.df) == 0)
        message("No results")
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Find Pathway WPIDs By ORCID 
#'
#' @description Retrieve list of pathway WPIDs containing the query ORCID
#' @param query The \code{character} ORCID to search for.
#' @return A \code{list} of WPIDs
#' @examples {
#' findPathwayIDsByOrcid(' 0000-0001-9773-4008')
#' }
#' @seealso findPathwaysByOrcid
#' @export 
findPathwayIDsByOrcid <- function(query=NULL) {
    res <- findPathwaysByOrcid(query)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway Names By ORCID 
#'
#' @description Retrieve list of pathway names containing the query ORCID
#' @param query The \code{character} ORCID to search for.
#' @return A \code{list} of lists
#' @examples {
#' findPathwayNamesByOrcid(' 0000-0001-9773-4008')
#' }
#' @seealso findPathwaysByOrcid
#' @export 
findPathwayNamesByOrcid <- function(query=NULL) {
    res <- findPathwaysByOrcid(query)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway URLs By ORCID 
#'
#' @description Retrieve list of pathway URLs containing the query ORCID
#' @param query The \code{character} ORCID to search for.
#' @return A \code{list} of lists
#' @examples {
#' findPathwayUrlsByOrcid(' 0000-0001-9773-4008')
#' }
#' @seealso findPathwaysByOrcid
#' @export 
findPathwayUrlsByOrcid <- function(query=NULL) {
    res <- findPathwaysByOrcid(query)
    return(res$url)
}

# ------------------------------------------------------------------------------
#' @title List Communities
#'
#' @description Retrieve the list of communities hosted by WikiPathways
#' @return A \code{data.frame} of community information
#' @examples {
#' listCommunities()
#' }
#' 
#' @export
listCommunities <- function() {
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/listCommunities.json")
    res.df <- res$communities %>%
        purrr::map_df(~as_tibble(.)) %>%
        tidyr::unnest_wider(pathways, names_sep = "_") %>%
        dplyr::select(c(1:5)) %>%
        unique()
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Get Pathways By Community
#'
#' @description Retrieve pathways per community
#' @param community_tag Abbreviated name of community
#' @return A \code{data.frame} of pathway information
#' @examples {
#' getPathwaysByCommunity("AOP")
#' }
#' 
#' @export
getPathwaysByCommunity <- function(community_tag=NULL) {
    if(is.null(community_tag))
        stop("Must provide a community_tag, e.g., AOP")
    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/listCommunities.json")
    res.df <- res$communities %>%
        purrr::map_df(~as_tibble(.)) %>%
        tidyr::unnest_wider(pathways, names_sep = "_") 
    
    if(!community_tag %in% res.df$`community-tag`)
        stop("Must provide a valid community_tag, e.g., AOP")
    
    res.df <- res.df %>%
        dplyr::filter(`community-tag` == community_tag) %>%
        dplyr::select(c(6:10)) %>%
        unique()
    
    names(res.df) <- sub("^pathways_", "", names(res.df))
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Get Pathway IDs By Community
#'
#' @description Retrieve the list of pathway IDs per community
#' @param community_tag Abbreviated name of community
#' @return A \code{list} of pathway IDs
#' @examples {
#' getPathwayIdsByCommunity("AOP")
#' }
#' 
#' @export
getPathwayIdsByCommunity <- function(community_tag=NULL) {
    res <- getPathwaysByCommunity(community_tag)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title Get Pathway Names By Community
#'
#' @description Retrieve the list of pathway names per community
#' @param community_tag Abbreviated name of community
#' @return A \code{list} of pathway names
#' @examples {
#' getPathwayNamesByCommunity("AOP")
#' }
#' 
#' @export
getPathwayNamesByCommunity <- function(community_tag=NULL) {
    res <- getPathwaysByCommunity(community_tag)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title Get Pathway URLs By Community
#'
#' @description Retrieve the list of pathway URLs per community
#' @param community_tag Abbreviated name of community
#' @return A \code{list} of pathway URLs
#' @examples {
#' getPathwayUrlsByCommunity("AOP")
#' }
#' 
#' @export
getPathwayUrlsByCommunity <- function(community_tag=NULL) {
    res <- getPathwaysByCommunity(community_tag)
    return(res$url)
}

# ==============================================================================
# Utility functions used by more than one rWikiPathways function. Typically, these 
# should not be exported, nor visible to package users. Add variable and functions 
# here if you suspect they will be useful for other developers. 
# 
# Dev Note: internal variables and functions should be prefixed with a '.'
# ------------------------------------------------------------------------------
# The base url for all WikiPathways API calls

.baseUrl <- 'https://webservice.wikipathways.org'


# ------------------------------------------------------------------------------
#' @title DEPRECATED: Open Swagger docs for WikiPathways API
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param base.url (optional) Ignore unless you need to specify a custom domain.
#' @return New tab in default browser
#' @importFrom utils browseURL
#' @export
wikipathwaysAPI <- function(base.url=.baseUrl){
    .Deprecated("https://wikipathways.org")
    
    if (interactive())
        browseURL(paste(base.url,'/ui',sep=""))
}

# ------------------------------------------------------------------------------
#' @title DEPRECATED: WikiPathways GET
#'
#' @description This function is provided for compatibility with older 
#' web services only and will be defunct at the next release.
#' @param operation A \code{character} string to be converted to the query 
#' namespace
#' @param parameters A named \code{list} of values to be converted to query 
#' parameters 
#' @param format (\code{character}) The format of the return, e.g., json 
#' (default), xml, html, jpg, pdf, dump
#' @param base.url (optional) Ignore unless you need to specify a custom domain.
#' @return query result content
#' @importFrom rjson fromJSON
#' @importFrom httr GET
#' @importFrom utils URLencode
#' @export
wikipathwaysGET <- function(operation, parameters=NULL, format=c('json','xml','html','jpg','pdf','dump'), base.url=.baseUrl){
    .Deprecated()
    
    q.url <- paste(base.url, operation, sep="/")
    
    format <- match.arg(format)
    
    if(!is.null(parameters)){
        q.params <- .prepGetQueryArgs(parameters)
        q.url <- paste(q.url, q.params, sep="?")
        q.url <- paste0(q.url, '&format=', format)
    } else {
        q.url <- paste0(q.url, '?format=', format)
    }
    
    res <- GET(url=URLencode(q.url))
    if(res$status_code > 299){
        write(sprintf("rwikipathways::wikipathwaysGET, HTTP Error Code: %d\n url=%s", 
                      res$status_code, URLencode(q.url)), stderr())
        stop()
    } else {
        if(length(res$content)>0){
            return(rjson::fromJSON(rawToChar(res$content)))
        } else{
            invisible(res)
        }
    }    
}

# ------------------------------------------------------------------------------
# Takes a named list and makes a string for GET query urls
#' @importFrom utils URLencode
.prepGetQueryArgs <- function(named.args){
    args1 <- names(named.args)
    args2 <- unlist(unname(named.args))
    q.args = paste(args1[1],URLencode(as.character(args2[1])),sep="=")
    for (i in seq(args1)[-1]){
        arg = paste(args1[i],URLencode(as.character(args2[i])),sep="=")
        q.args = paste(q.args,arg,sep="&")
    }
    return(q.args)
}

# ------------------------------------------------------------------------------
#' @title Get Ontology Terms by Pathway
#'
#' @description Retrieve information about ontology terms for a specific pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway, e.g. WP554. If
#' NULL, then ontology term information for all pathways is returned.
#' @return A \code{data.frame} pathway id and term information
#' @examples {
#' getOntologyTerms('WP554')
#' }
#' @export
getOntologyTerms <- function(pathway=NULL) {
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/getOntologyTermsByPathway.json")
    res.df <- res$pathways %>%
        purrr::map_df(~as_tibble(.)) %>%
        tidyr::unnest_wider(terms, names_sep = "_")
    
    if(!is.null(pathway))
        res.df <- dplyr::filter(res.df, id == pathway)
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Get Ontology Term Names by Pathway
#'
#' @description Retrieve names of ontology terms for a specific pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @return A \code{list} of term names
#' @examples {
#' getOntologyTermNames('WP554')
#' }
#' @export
getOntologyTermNames <- function(pathway=NULL) {
    return(unique(getOntologyTerms(pathway)$terms_name))
}

# ------------------------------------------------------------------------------
#' @title Get Ontology Term IDs by Pathway
#'
#' @description Retrieve identifiers of ontology terms for a specific pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @return A \code{list} of term identifiers
#' @examples {
#' getOntologyTermIds('WP554')
#' }
#' @export
getOntologyTermIds <- function(pathway=NULL) {
    return(unique(getOntologyTerms(pathway)$terms_id))
}


# ------------------------------------------------------------------------------
#' @title Get Pathways by Ontology Term 
#'
#' @description Retrieve pathway information for every pathway with a given ontology term.
#' @param term (\code{character}) Official ID of ontology term, e.g., "PW:0000045"
#' @return A \code{data.frame} of pathway information
#' @examples {
#' getPathwaysByOntologyTerm('PW:0000045')
#' }
#' @export
getPathwaysByOntologyTerm <- function(term=NULL) {    
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/getPathwaysByOntologyTerm.json")
    res.df <- res$terms %>%
        purrr::map_df(~as_tibble(.)) %>%
        tidyr::unnest_wider(pathways, names_sep = "_")

if(!is.null(term))
    res.df <- dplyr::filter(res.df, id == term)

return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Get Pathway WPIDs by Ontology Term 
#'
#' @description Retrieve pathway WPIDs for every pathway with a given ontology term.
#' @param term (\code{character}) Official ID of ontology term, e.g., "PW:0000045"
#' @return A \code{list} of pathway WPIDs
#' @examples {
#' getPathwayIdsByOntologyTerm('PW:0000045')
#' }
#' @export
getPathwayIdsByOntologyTerm <- function(term=NULL) {
    return(unique(getPathwaysByOntologyTerm(term)$pathways_id))
}

# ------------------------------------------------------------------------------
#' @title Get Pathways by Parent Ontology Term 
#'
#' @description Retrieve pathway information for every pathway with a child term of given ontology term.
#' @param term (\code{character}) Official name of ontology term, e.g., "signaling pathway"
#' @return A \code{data.frame} of pathway information
#' @examples {
#' getPathwaysByParentOntologyTerm('signaling pathway')
#' }
#' @export
getPathwaysByParentOntologyTerm <- function(term=NULL) {
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/getOntologyTermsByPathway.json")
    res.df <- res$pathways %>%
        purrr::map_df(~as_tibble(.)) %>%
        tidyr::unnest_wider(terms, names_sep = "_")
    
    if(!is.null(term))
        res.df <- dplyr::filter(res.df, terms_parent == term)
    
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title Get Pathway WPIDs by Parent Ontology Term 
#'
#' @description Retrieve pathway WPIDs for every pathway with a child term of given ontology term
#' @param term (\code{character}) Official name of ontology term, e.g., "signaling pathway"
#' @return A \code{list} of pathway WPIDs
#' @examples {
#' getPathwayIdsByParentOntologyTerm('signaling pathway')
#' }
#' @export
getPathwayIdsByParentOntologyTerm <- function(term=NULL) {
    return(unique(getPathwaysByParentOntologyTerm(term)$pathways_id))
}

library(rWikiPathways)
context("Annotation")

test_that("get by WPID", {
    terms = getOntologyTerms('WP554')
    expect_gt(length(terms), 0)
})

test_that("find by ontology term", {
    pathways = getPathwaysByOntologyTerm('PW:0000045')
    expect_gt(length(pathways), 0)
})

test_that("find by parent ontology term", {
    pathways = getPathwaysByParentOntologyTerm('PW:0000045')
    expect_gt(length(pathways), 0)
})

# ------------------------------------------------------------------------------
#' @title Read Pathway GMT File
#'
#' @description Reads a WikiPathways GMT file to produce a data frame of 
#' pathway-gene associations useful in enrichment analyses and other 
#' applications.
#' @param file Path to GMT file 
#' @return Data frame of pathway-gene associations
#' @details The returned data frame includes pathway name, version, identifier,
#' and organism. The gene content is provided as NCBI Entrez Gene identifiers.
#' The input file can be retrieved by using 
#' \code{downloadPathwayArchive(organism="Homo sapiens",format="gmt")}.
#' @references Adapted from the generic GMT reader provided by clusterProfiler,
#'  \url{https://github.com/YuLab-SMU/clusterProfiler/blob/master/R/GMT.R}
#' @examples \donttest{
#' #readPathwayGMT(system.file("extdata",
#' #  "wikipathways-20201010-gmt-Homo_sapiens.gmt", package="rWikiPathways"))
#' }
#' @seealso downloadPathwayArchive
#' @export
#' @importFrom tidyr separate
#' @importFrom utils stack
readPathwayGMT <- function(file) {
  x <- readLines(file)
  res <- strsplit(x, "\t")
  names(res) <- vapply(res, function(y) y[1], character(1))
  res <- lapply(res, "[", -c(1:2))
  
  wp2gene <- stack(res)
  wp2gene <- wp2gene[, c("ind", "values")]
  colnames(wp2gene) <- c("pathway", "gene")
  wp2gene <- tidyr::separate(wp2gene, pathway, c("name","version","wpid","org"), "%")
  return(wp2gene)
}

# ------------------------------------------------------------------------------
#' @title Get Counts for WikiPathways Stats
#'
#' @description Retrieve information about various total counts at WikiPathways.
#' @return A \code{data.frame} of counts
#' @examples {
#' getCounts()
#' }
#' @export
getCounts <- function() {
    
    res<-rjson::fromJSON(
        file="https://www.wikipathways.org/json/getCounts.json")
    
    return(as.data.frame(res))
}

# ------------------------------------------------------------------------------
#' @title List Pathways
#'
#' @description Retrieve list of pathways per species, including WPID, name, 
#' species, URL and latest revision number.
#' @param organism (\code{character}, optional) A particular species. 
#' See \link{listOrganisms}. Default is all species.
#' @return A \code{dataframe} of pathway information
#' @examples {
#' listPathways('Mus musculus')
#' }
#' @export
#' @importFrom data.table rbindlist
listPathways <- function(organism="") {
    res <- rjson::fromJSON(file="https://www.wikipathways.org/json/listPathways.json")
    res.df <- res$organisms %>% 
        purrr::map_dfr(~ .x$pathways) 
    if(organism != ""){
        res.df <- dplyr::filter(res.df, species == organism)
    }
    if(nrow(res.df) == 0){
        message("No results")
    }
    return(as.data.frame(res.df))
}

# ------------------------------------------------------------------------------
#' @title List Pathway WPIDs
#'
#' @description Retrieve list of pathway WPIDs per species. 
#' @details Basically returns a subset of \link{listPathways} result
#' @param organism (\code{character}, optional) A particular species. 
#' See \link{listOrganisms}. 
#' Default is all species.
#' @return A \code{list} of WPIDs
#' @examples {
#' listPathwayIds('Mus musculus')
#' }
#' @seealso listPathways
#' @export 
listPathwayIds <- function(organism="") {
    res <- listPathways(organism)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title List Pathway Names
#'
#' @description Retrieve list of pathway names per species. 
#' @details Basically returns a subset of \link{listPathways} result
#' @param organism (\code{character}, optional) A particular species. 
#' See \link{listOrganisms}. 
#' Default is all species.
#' @return A \code{list} of names
#' @examples {
#' listPathwayNames('Mus musculus')
#' }
#' @seealso listPathways
#' @export 
listPathwayNames <- function(organism="") {
    res <- listPathways(organism)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title List Pathway URLs
#'
#' @description Retrieve list of pathway URLs per species. 
#' @details Basically returns a subset of \link{listPathways} result
#' @param organism (\code{character}, optional) A particular species. 
#' See \link{listOrganisms}. 
#' Default is all species.
#' @return A \code{list} of URLs
#' @examples {
#' listPathwayUrls('Mus musculus')
#' }
#' @seealso listPathways
#' @export 
listPathwayUrls <- function(organism="") {
    res <- listPathways(organism)
    return(res$url)
}

library(rWikiPathways)
context("Lists")

test_that("pathways are found", {
  organisms = listPathways()
  expect_gt(length(organisms), 0)
})

test_that("Anopheles gambiae pathways are found", {
  organisms = listPathways(organism="Anopheles gambiae")
  expect_gt(length(organisms), 0)
})

# ------------------------------------------------------------------------------
#' @title Get Curation Tags on a Pathway
#'
#' @description Retrieve information about curation tags for a specific pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @return A \code{list} of tag name, display name, revision, text, timestampe and user
#' @examples {
#' getCurationTags('WP554')
#' }
#' @export
getCurationTags <- function(pathway) {
    res <- wikipathwaysGET('getCurationTags',list(pwId=pathway))
    return(unname(res$tags))
}

# ------------------------------------------------------------------------------
#' @title Get Curation Tag Names on a Pathway
#'
#' @description Retrieve names of curation tags for a specific pathway.
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @return A \code{list} of tag names
#' @examples {
#' getCurationTagNames('WP554')
#' }
#' @export
getCurationTagNames <- function(pathway) {
    unlist(lapply(getCurationTags(pathway), function(x) {unname(x['name'])}))
}

# ------------------------------------------------------------------------------
#' @title Get Every Instance of a Curation Tag
#'
#' @description Retrieve information about every instance of a given curation tag.
#' @param tag (\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"
#' @return A \code{list} of tag name, display name, revision, text, timestampe and user
#' @examples {
#' getEveryCurationTag('Curation:FeaturedPathway')
#' }
#' @export
getEveryCurationTag <- function(tag) {
    res <- wikipathwaysGET('getCurationTagsByName',list(tagName=tag))
    return(unname(res$tags))
}

# ------------------------------------------------------------------------------
#' @title Get Pathways by Curation Tag 
#'
#' @description Retrieve pathway information for every pathway with a given curation tag.
#' @param tag (\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"
#' @return A \code{list} of pathway information, including WPID, url, name, species and revision
#' @examples {
#' getPathwaysByCurationTag('Curation:FeaturedPathway')
#' }
#' @export
getPathwaysByCurationTag <- function(tag) {
    pathway.list <- lapply(getEveryCurationTag(tag), function(x) {unname(x['pathway'])})
    lapply(pathway.list, unlist)
}

# ------------------------------------------------------------------------------
#' @title Get Pathway WPIDs by Curation Tag 
#'
#' @description Retrieve pathway WPIDs for every pathway with a given curation tag.
#' @param tag (\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"
#' @return A \code{list} of pathway WPIDs
#' @examples {
#' getPathwayIdsByCurationTag('Curation:FeaturedPathway')
#' }
#' @export
getPathwayIdsByCurationTag <- function(tag) {
    p.info.list <- lapply(getEveryCurationTag(tag), function(x) {unname(x['pathway'])})
    p.info <- lapply(p.info.list, unlist)
    unlist(lapply(p.info,function(x) {unname(x['id'])}))
}

# ------------------------------------------------------------------------------
#' @title Find Pathways By Text
#'
#' @description Retrieve pathways containing the query text.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @return A \code{dataframe} of pathway attributes in addition to query result 
#' score
#' @details The score is from a lucene index search engine, ranging from 0 to 
#' 1 with higher scores for better matches. 
#' @examples {
#' findPathwaysByText('cancer')
#' }
#' @export
findPathwaysByText <- function(query) {
    res <- wikipathwaysGET('findPathwaysByText', list(query=query))
    if(length(res$result) == 0){
        message("No results")
        return(data.frame())
    }
    res.df <- suppressWarnings(data.table::rbindlist(res$result, fill = TRUE))
    res.df$fields <- NULL
    res.df$revision <- vapply(res.df$revision, as.integer, integer(1))
    res.df$score <- vapply(res.df$score, function(s){
        as.numeric(unlist(s))
    }, numeric(1))
    return(res.df)
    
}

# ------------------------------------------------------------------------------
#' @title Find Pathway WPIDs By Text 
#'
#' @description Retrieve list of pathway WPIDs containing the query text.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @return A \code{list} of WPIDs
#' @examples {
#' findPathwayIdsByText('cancer')
#' }
#' @seealso findPathwaysByText
#' @export 
findPathwayIdsByText <- function(query) {
    res <- findPathwaysByText(query)
    return(res$id)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway Names By Text 
#'
#' @description Retrieve list of pathway names containing the query text.
#' @details Note: there will be multiple listings of the same pathway name if 
#' copies exist for multiple species.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @return A \code{list} of pathway names
#' @examples {
#' findPathwayNamesByText('cancer')
#' }
#' @seealso findPathwaysByText
#' @export 
findPathwayNamesByText <- function(query) {
    res <- findPathwaysByText(query)
    return(res$name)
}

# ------------------------------------------------------------------------------
#' @title Find Pathway URLs By Text 
#'
#' @description Retrieve list of pathway URLs containing the query text.
#' @param query A \code{character} string to search for, e.g., "cancer"
#' @return A \code{list} of urls
#' @examples {
#' findPathwayUrlsByText('cancer')
#' }
#' @seealso findPathwaysByText
#' @export 
findPathwayUrlsByText <- function(query) {
    res <- findPathwaysByText(query)
    return(res$url)
}

# ------------------------------------------------------------------------------
#' @title Defunct: Get Colored Pathway
#'
#' @description This service is no longer available and is defunct in 
#' this release and will be removed in the next release. 
#' @param pathway WikiPathways identifier (WPID) for the pathway to download, e.g. WP4
#' @param revision (\code{integer}, optional) Number to indicate a specific revision to download
#' @param graphId A \code{character} string or \code{vector} indicating the nodes to color 
#' @param color (optional) String or vector indicating the highlighting color, e.g., #FF8855.
#' Default is red. You can provide a single color for mutiple nodes; otherwise
#' color list and graphId must be the same length.
#' @param fileType (optional) Image file format, e.g., svg (default), png or pdf.
#' @return Image file
#' @export
getColoredPathway <- function(pathway, revision=0,
                              graphId=NULL, color=NULL,
                              fileType=c("svg","png","pdf")) {
  
  .Defunct(NULL, msg="This service is no longer available It is defunct in this release.")
  
  #   fileType <- match.arg(fileType)
  #   
  #   if (is.null(color)&&!is.null(graphId)) {
  #       color = rep("FF0000", length(graphId))
  #   } else if (length(color) == 1) {
  #       color = rep(color, length(graphId))
  #   }
  #   
  #   if(length(graphId) != length(color))
  #       stop("Error: Must provide same number of graphIds and colors.")
  #   
  #   # if these are still null, then swap for strings to avoid complications
  #   if(is.null(graphId))
  #           graphId="NULL"
  #   if(is.null(color))
  #           color="NULL"
  #   
  #   # finally, prepare parameters as named list,
  #   # handling multiple named items for graphId and color
  #   params <- list(pwId=pathway,
  #                  revision=revision,
  #                  fileType=fileType)
  #   for (gi in graphId)
  #       params <- c(params, graphId=gi)
  #   for (co in color)
  #       params <- c(params, color=co)
  # 
  #   res <- wikipathwaysGET('getColoredPathway', params) 
  # 
  #   img = caTools::base64decode(res['data'],what='character')
  # 
  # return(img)
}

---
title: "rWikiPathways and RCy3"
author: "by Alexander Pico"
package: rWikiPathways
date: "`r Sys.Date()`"
output: 
  BiocStyle::html_document:
    toc_float: true
    includes:
      in_header: rWikiPathways-and-RCy3-schema.html
#  pdf_document:
#    toc: true 
vignette: >
  %\VignetteIndexEntry{3. rWikiPathways and RCy3}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---
```{r, echo = FALSE}
knitr::opts_chunk$set(
  eval=FALSE
)
```

*WikiPathways* is a well-known repository for biological pathways that provides unique tools to the research community for content creation, editing and utilization [@Pico2008].

**R** is a powerful programming language and environment for statistical and exploratory data analysis.

*rWikiPathways* leverages the WikiPathways API to communicate between **R** and WikiPathways, allowing any pathway to be queried, interrogated and downloaded in both data and image formats. Queries are typically performed based on "Xrefs", standardized identifiers for genes, proteins and metabolites. Once you can identified a pathway, you can use the WPID (WikiPathways identifier) to make additional queries.

*RCy3* leverages the CyREST API to provide a number of functions related to network visualization and analysis.

# Prerequisites

In addition to this **rWikiPathways** package, you'll also need to install **RCy3**:

```{r}
if(!"rWikiPathways" %in% installed.packages()){
    if (!requireNamespace("BiocManager", quietly=TRUE))
        install.packages("BiocManager")
    BiocManager::install("rWikiPathways")
}
library(rWikiPathways)
if(!"RCy3" %in% installed.packages()){
    if (!requireNamespace("BiocManager", quietly=TRUE))
        install.packages("BiocManager")
    BiocManager::install("RCy3")
}
library(RCy3)
```

The whole point of RCy3 is to connect with Cytoscape. You will need to install and launch Cytoscape:

* Download the latest Cytoscape from http://www.cytoscape.org/download.php
* Complete installation wizard
* Launch Cytoscape

```{r}
cytoscapePing()
```

For this vignette, you'll also need the WikiPathways app to access the WikiPathways database from within Cytoscape. Install the WikiPathways app from http://apps.cytoscape.org/apps/wikipathways

If you are running Cytoscape 3.7.0 or above, you can simply run this command:
```
installApp('WikiPathways')  #only available in Cytoscape 3.7.0 and above
```

# Working together
Ok, with all of these components loaded and launched, you can now perform some nifty sequences. For example, search for a pathway based on a keyword search and then load it into Cytoscape.

```{r}
gbm.pathways <- findPathwaysByText('Glioblastoma') # many pathways returned
human.gbm.pathways <- gbm.pathways %>% 
  dplyr::filter(species == "Homo sapiens") # just the human gbm  pathways
```

We have a list of human pathways that mention Glioblastoma The results include lots of information, so let's get a unique list of just the WPIDs.
```{r}
human.gbm.wpids <- human.gbm.pathways$id
```

Let's import the first one of these into Cytoscape!
```{r}
commandsRun(paste0('wikipathways import-as-pathway id=',human.gbm.wpids[1])) 
```

Once in Cytoscape, you can load data, apply visual style mappings, perform analyses, and export images and data formats. See RCy3 package vignettes for details.

# From networks to pathways
If you are already with with networks and data in Cytoscape, you may end up focusing on one or few particular genes, proteins or metabolites, and want to query WikiPathways.

For example, let's open a sample network from Cytoscape and identify the gene with the largest number of connections, i.e., node degree.

**Note: this next chunk will overwrite your current session. Save if you want to keep anything.**
```{r}
openSession()
net.data <- getTableColumns(columns=c('name','degree.layout','COMMON'))
max.gene <- net.data[which.max(unlist(net.data['degree.layout'])),]
max.gene
```
Great. It looks like MCM1 has the larget number of connections (18) in this network. Let's use it's identifier (YMR043W) to query WikiPathways to learn more about the gene and its biological role, and load it into Cytoscape.

*Pro-tip: We need to know the datasource that provides a given identifier. In this case, it's sort of tricky: Ensembl provides these Yeast ORF identifiers for this organism rather than they typical format. So, we'll include the 'En' system code. See other vignettes for more details.*
```{r}
mcm1.pathways <-unique(findPathwayIdsByXref('YMR043W','En'))
commandsRun(paste0('wikipathways import-as-pathway id=', mcm1.pathways[1]))
```

And we can easily select the MCM1 node by name in the newly imported pathway to help see where exactly it plays its role.

```{r}
selectNodes('MCM1','name')
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listCommunities.R
\name{listCommunities}
\alias{listCommunities}
\title{List Communities}
\usage{
listCommunities()
}
\value{
A \code{data.frame} of community information
}
\description{
Retrieve the list of communities hosted by WikiPathways
}
\examples{
{
listCommunities()
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getOntologyTerms.R
\name{getPathwayIdsByOntologyTerm}
\alias{getPathwayIdsByOntologyTerm}
\title{Get Pathway WPIDs by Ontology Term}
\usage{
getPathwayIdsByOntologyTerm(term)
}
\arguments{
\item{term}{(\code{character}) Official name of ontology term, e.g., "PW:0000045"}
}
\value{
A \code{list} of pathway WPIDs
}
\description{
Retrieve pathway WPIDs for every pathway with a given ontology term.
}
\examples{
{
getPathwayIdsByOntologyTerm('PW:0000045')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getXrefList.R
\name{getXrefList}
\alias{getXrefList}
\title{Get Xref List}
\usage{
getXrefList(pathway, systemCode)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, 
e.g. WP4}

\item{systemCode}{(\code{character}) The BridgeDb code associated with the 
data source or system, 
e.g., En (Ensembl), L (Entrez), Ch (HMDB), etc. See column two of 
https://github.com/bridgedb/datasources/blob/main/datasources.tsv.}
}
\value{
A \code{list} of Xrefs identifiers
}
\description{
Retrieve the Xref identifiers for a specific pathway in a 
particular system code
}
\examples{
{
xrefs = getXrefList("WP2338", "L")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/writeGMT.R
\name{writeGMT}
\alias{writeGMT}
\title{Write GMT File}
\usage{
writeGMT(df, outfile)
}
\arguments{
\item{df}{Data frame with columns ordered as Identifiers, optional 
Description column and Genes. Identifiers must be first and Genes must be 
last.}

\item{outfile}{Path to output GMT file}
}
\value{
None
}
\description{
Writes a GMT (Gene Matrix Transposed) file from a data frame.
}
\details{
The input data frame must include at least two columns: Identifiers
(first column) and Genes (last column). The Identifiers will be duplicated to
fill the Description column in the output GMT file if none is provided. If 
more than three columns are provided, then the first n columns will be 
concatenated with % separators to form the ID, where n+2 equals the total
number of columns.
}
\examples{
\donttest{
my.df <- data.frame(id=c("WP1000","WP1000","WP1000","WP1001","WP1001"),
         description=c("cancer","cancer","cancer","diabetes","diabetes"),
         gene=c("574413","2167","4690","5781","11184"))
writeGMT(my.df, "my_gmt_file.gmt")
}
}
\references{
Adapted from the GMT writer in MAGeCKFlute,
 \url{https://github.com/WubingZhang/MAGeCKFlute/blob/master/R/readGMT.R}
}
\seealso{
readPathwayGMT
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getPathway.R
\name{getPathway}
\alias{getPathway}
\title{Get Pathway}
\usage{
getPathway(pathway, revision = 0)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, e.g. WP4}

\item{revision}{(\code{integer}, optional) Number to indicate a specific revision to download}
}
\value{
GPML
}
\description{
Retrieve a specific pathway in the GPML format
}
\examples{
{
getPathway('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByOrcid.R
\name{findPathwaysByOrcid}
\alias{findPathwaysByOrcid}
\title{Find Pathways By ORCID}
\usage{
findPathwaysByOrcid(query = NULL)
}
\arguments{
\item{query}{The \code{character} ORCID to search for.}
}
\value{
A \code{dataframe} of pathway attributes including the matching
ORCIDs
}
\description{
Retrieve pathways containing the query ORCID
}
\examples{
{
findPathwaysByOrcid(' 0000-0001-9773-4008')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCurationTags.R
\name{getEveryCurationTag}
\alias{getEveryCurationTag}
\title{Get Every Instance of a Curation Tag}
\usage{
getEveryCurationTag(tag)
}
\arguments{
\item{tag}{(\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"}
}
\value{
A \code{list} of tag name, display name, revision, text, timestampe and user
}
\description{
Retrieve information about every instance of a given curation tag.
}
\examples{
{
getEveryCurationTag('Curation:FeaturedPathway')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readPathwayGMT.R
\name{readPathwayGMT}
\alias{readPathwayGMT}
\title{Read Pathway GMT File}
\usage{
readPathwayGMT(file)
}
\arguments{
\item{file}{Path to GMT file}
}
\value{
Data frame of pathway-gene associations
}
\description{
Reads a WikiPathways GMT file to produce a data frame of 
pathway-gene associations useful in enrichment analyses and other 
applications.
}
\details{
The returned data frame includes pathway name, version, identifier,
and organism. The gene content is provided as NCBI Entrez Gene identifiers.
The input file can be retrieved by using 
\code{downloadPathwayArchive(organism="Homo sapiens",format="gmt")}.
}
\examples{
\donttest{
readPathwayGMT(system.file("extdata","wikipathways-20201010-gmt-Homo_sapiens.gmt", package="rWikiPathways"))
}
}
\references{
Adapted from the generic GMT reader provided by clusterProfiler,
 \url{https://github.com/YuLab-SMU/clusterProfiler/blob/master/R/GMT.R}
}
\seealso{
downloadPathwayArchive
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/downloadPathwayArchive.R
\name{downloadPathwayArchive}
\alias{downloadPathwayArchive}
\title{Download Pathway Archive}
\usage{
downloadPathwayArchive(
  date = "current",
  organism = NULL,
  format = c("gpml", "gmt", "svg"),
  destpath = "./"
)
}
\arguments{
\item{date}{(optional) The timestamp for a monthly release (e.g., 20171010) 
or "current" (default) for latest release.}

\item{organism}{(optional) A particular species. See \link{listOrganisms}.}

\item{format}{(optional) Either gpml (default), gmt or svg.}

\item{destpath}{(optional) Destination path for file to be downloaded to.
Default is current workding directory.}
}
\value{
Filename of downloaded file or an opened tab in default browser
}
\description{
Access the monthly archives of pathway content from WikiPathways.
}
\details{
If you do not specify an organism, then an archive file
will not be downloaded. Rather, the archive will be opened in a tab in your
default browser.
}
\examples{
\donttest{
downloadPathwayArchive()  ## open in browser
downloadPathwayArchive(format="gmt")  ## open in browser
downloadPathwayArchive(date="20171010", format="svg")  ## open in browser
downloadPathwayArchive(date="20171010", organism="Mus musculus", format="svg")  ## download file
downloadPathwayArchive(organism="Mus musculus")  ## download file
}
}
\seealso{
readPathwayGMT
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByText.R
\name{findPathwaysByText}
\alias{findPathwaysByText}
\title{Find Pathways By Text}
\usage{
findPathwaysByText(query = NULL, field = NULL)
}
\arguments{
\item{query}{A \code{character} string to search for, e.g., "cancer". Case 
insensitive.}

\item{field}{Optional \code{character} string to restrict search to a single
field, e.g., id, name, description, species, revision, authors,
datanodes, annotations, or citedIn.}
}
\value{
A \code{dataframe} of pathway attributes including the matching
attributes
}
\description{
Retrieve pathways matching the query text.
}
\details{
Searches id, name, description, species, revision date, authors,
datanode labels, ontology annotations, and citedIn (e.g., PMCIDs).
}
\examples{
{
findPathwaysByText('cancer')
findPathwaysByText('cancer','name')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listPathways.R
\name{listPathwayNames}
\alias{listPathwayNames}
\title{List Pathway Names}
\usage{
listPathwayNames(organism = "")
}
\arguments{
\item{organism}{(\code{character}, optional) A particular species. See \link{listOrganisms}. 
Default is all species.}
}
\value{
A \code{list} of names
}
\description{
Retrieve list of pathway names per species.
}
\details{
Basically returns a subset of \link{listPathways} result
}
\examples{
{
listPathwayNames('Mus musculus')
}
}
\seealso{
listPathways
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwayByText.R
\name{findPathwayIdsByText}
\alias{findPathwayIdsByText}
\title{Find Pathway WPIDs By Text}
\usage{
findPathwayIdsByText(query)
}
\arguments{
\item{query}{A \code{character} string to search for, e.g., "cancer"}
}
\value{
A \code{list} of WPIDs
}
\description{
Retrieve list of pathway WPIDs containing the query text.
}
\examples{
{
findPathwayIdsByText('cancer')
}
}
\seealso{
findPathwaysByText
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utilities.R
\name{wikipathwaysGET}
\alias{wikipathwaysGET}
\title{WikiPathways GET}
\usage{
wikipathwaysGET(
  operation,
  parameters = NULL,
  format = c("json", "xml", "html", "jpg", "pdf", "dump"),
  base.url = .baseUrl
)
}
\arguments{
\item{operation}{A \code{character} string to be converted to the query namespace}

\item{parameters}{A named \code{list} of values to be converted to query parameters}

\item{format}{(\code{character}) The format of the return, e.g., json (default), xml, html, jpg, pdf, dump}

\item{base.url}{(optional) Ignore unless you need to specify a custom domain.}
}
\value{
query result content
}
\description{
Constructs the query, makes GET call and processes the result
}
\examples{
{
wikipathwaysGET('listOrganisms')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listCommunities.R
\name{getPathwayNamesByCommunity}
\alias{getPathwayNamesByCommunity}
\title{Get Pathway Names By Community}
\usage{
getPathwayNamesByCommunity(community_tag = NULL)
}
\arguments{
\item{community_tag}{Abbreviated name of community}
}
\value{
A \code{list} of pathway names
}
\description{
Retrieve the list of pathway names per community
}
\examples{
{
getPathwayNamesByCommunity("AOP")
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listPathways.R
\name{listPathways}
\alias{listPathways}
\title{List Pathways}
\usage{
listPathways(organism = "")
}
\arguments{
\item{organism}{(\code{character}, optional) A particular species. See \link{listOrganisms}. 
Default is all species.}
}
\value{
A \code{dataframe} of pathway information
}
\description{
Retrieve list of pathways per species, including WPID, name, species,
URL and latest revision number.
}
\examples{
{
listPathways('Mus musculus')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listCommunities.R
\name{getPathwayIdsByCommunity}
\alias{getPathwayIdsByCommunity}
\title{Get Pathway IDs By Community}
\usage{
getPathwayIdsByCommunity(community_tag = NULL)
}
\arguments{
\item{community_tag}{Abbreviated name of community}
}
\value{
A \code{list} of pathway IDs
}
\description{
Retrieve the list of pathway IDs per community
}
\examples{
{
getPathwayIdsByCommunity("AOP")
}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utilities.R
\name{wikipathwaysAPI}
\alias{wikipathwaysAPI}
\title{Open Swagger docs for WikiPathways API}
\usage{
wikipathwaysAPI(base.url = .baseUrl)
}
\arguments{
\item{base.url}{(optional) Ignore unless you need to specify a custom domain.}
}
\value{
New tab in default browser
}
\description{
Opens swagger docs in default browser for available API calls.
}
\examples{
{
wikipathwaysAPI()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByXref.R
\name{findPathwayIdsByXref}
\alias{findPathwayIdsByXref}
\title{Find Pathway WPIDs By Xref}
\usage{
findPathwayIdsByXref(identifier = NULL, systemCode = NULL)
}
\arguments{
\item{identifier}{(\code{character}) The official ID specified by a data 
source or system}

\item{systemCode}{(\code{character}) The BridgeDb code associated with the 
data source or system, 
e.g., En (Ensembl), L (Entrez), Ch (HMDB), etc. See column two of 
https://github.com/bridgedb/datasources/blob/main/datasources.tsv.}
}
\value{
A \code{list} of WPIDs
}
\description{
Retrieve list of pathway WPIDs containing the query Xref by 
identifier and system code.
}
\examples{
{
findPathwayIdsByXref('ENSG00000100031','En')
}
}
\seealso{
findPathwaysByXref
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByLiterature.R
\name{findPathwayNamesByLiterature}
\alias{findPathwayNamesByLiterature}
\title{Find Pathway Names By Literature}
\usage{
findPathwayNamesByLiterature(query)
}
\arguments{
\item{query}{The \code{character} string to search for, e.g., a PMID, title 
keyword or author name.}
}
\value{
A \code{list} of lists
}
\description{
Retrieve list of pathway names containing the query citation.
}
\details{
Note: there will be multiple listings of the same pathway name if 
copies exist for multiple species.
}
\examples{
{
findPathwayNamesByLiterature('19649250')
findPathwayNamesByLiterature('smith')
findPathwayNamesByLiterature('cancer')
}
}
\seealso{
findPathwaysByLiterature
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCurationStatus.R
\name{getPathwaysByCurationTag}
\alias{getPathwaysByCurationTag}
\title{DEPRECATED: Get Pathways by Curation Tag}
\usage{
getPathwaysByCurationTag(tag)
}
\arguments{
\item{tag}{(\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"}
}
\value{
A \code{list} of pathway information, including WPID, url, name, species and revision
}
\description{
This function is provided for compatibility with older 
web services only and will be defunct at the next release.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getPathwayHistory.R
\name{getPathwayHistory}
\alias{getPathwayHistory}
\title{Get Pathway History}
\usage{
getPathwayHistory(pathway = NULL, timestamp = NULL)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway, e.g. WP554}

\item{timestamp}{<ignored>}
}
\value{
Opens the GitHub history for a pathway
}
\description{
View the revision history of a pathway.
}
\examples{
\donttest{
#getPathwayHistory('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCurationTags.R
\name{getPathwayIdsByCurationTag}
\alias{getPathwayIdsByCurationTag}
\title{Get Pathway WPIDs by Curation Tag}
\usage{
getPathwayIdsByCurationTag(tag)
}
\arguments{
\item{tag}{(\code{character}) Official name of curation tag, e.g., "Curation:FeaturedPathway"}
}
\value{
A \code{list} of pathway WPIDs
}
\description{
Retrieve pathway WPIDs for every pathway with a given curation tag.
}
\examples{
{
getPathwayIdsByCurationTag('Curation:FeaturedPathway')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getRecentChanges.R
\name{getRecentChanges}
\alias{getRecentChanges}
\title{Get Recent Changes}
\usage{
getRecentChanges(timestamp = NULL)
}
\arguments{
\item{timestamp}{(8 digits, YYYYMMDD) Limit by time, only pathways changed 
after the given date, e.g., 20180201 for changes since Feb 1st, 2018.}
}
\value{
A \code{data.frame} of recently changed pathways, including id, name,
url, species and revision
}
\description{
Retrieve recently changed pathways at WikiPathways.
}
\examples{
{
getRecentChanges('20180201')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listOrganisms.R
\name{listOrganisms}
\alias{listOrganisms}
\title{List Organisms}
\usage{
listOrganisms()
}
\value{
A \code{list} of organisms
}
\description{
Retrieve the list of organisms supported by WikiPathways
}
\examples{
{
listOrganisms()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getOntologyTerms.R
\name{getOntologyTerms}
\alias{getOntologyTerms}
\title{Get Ontology Terms by Pathway}
\usage{
getOntologyTerms(pathway = NULL)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway, e.g. WP554. If
NULL, then ontology term information for all pathways is returned.}
}
\value{
A \code{data.frame} pathway id and term information
}
\description{
Retrieve information about ontology terms for a specific pathway.
}
\examples{
{
getOntologyTerms('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getColoredPathway.R
\name{getColoredPathway}
\alias{getColoredPathway}
\title{Defunct: Get Colored Pathway}
\usage{
getColoredPathway(
  pathway,
  revision = 0,
  graphId = NULL,
  color = NULL,
  fileType = c("svg", "png", "pdf")
)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, e.g. WP4}

\item{revision}{(\code{integer}, optional) Number to indicate a specific revision to download}

\item{graphId}{A \code{character} string or \code{vector} indicating the nodes to color}

\item{color}{(optional) String or vector indicating the highlighting color, e.g., #FF8855.
Default is red. You can provide a single color for mutiple nodes; otherwise
color list and graphId must be the same length.}

\item{fileType}{(optional) Image file format, e.g., svg (default), png or pdf.}
}
\value{
Image file
}
\description{
This service is no longer available and is defunct in 
this release and will be removed in the next release.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getOntologyTerms.R
\name{getPathwaysByOntologyTerm}
\alias{getPathwaysByOntologyTerm}
\title{Get Pathways by Ontology Term}
\usage{
getPathwaysByOntologyTerm(term = NULL)
}
\arguments{
\item{term}{(\code{character}) Official ID of ontology term, e.g., "PW:0000045"}
}
\value{
A \code{data.frame} of pathway information
}
\description{
Retrieve pathway information for every pathway with a given ontology term.
}
\examples{
{
getPathwaysByOntologyTerm('PW:0000045')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readGMT.R
\name{readGMT}
\alias{readGMT}
\title{Read GMT File}
\usage{
readGMT(file)
}
\arguments{
\item{file}{Path to GMT file}
}
\value{
Data frame of term-gene associations
}
\description{
Reads any generic GMT file to produce a data frame of 
term-gene associations useful in enrichment analyses and other 
applications.
}
\details{
The returned data frame includes only terms and genes. If you want
another data frame with terms and names, then see readGMTnames.
}
\examples{
\donttest{
readGMT(system.file("extdata","my_gmt_file.gmt", package="rWikiPathways"))
}
}
\seealso{
readGMTnames
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getRecentChanges.R
\name{getRecentChangesNames}
\alias{getRecentChangesNames}
\title{Get Pathway Names of Recent Changes}
\usage{
getRecentChangesNames(timestamp)
}
\arguments{
\item{timestamp}{(14 digits, YYYYMMDDhhmmss) Limit by time, only history items 
after the given time, e.g., 20180201000000 for changes since Feb 1st, 2018.}
}
\value{
A \code{list} of pathway names. Note: pathway deletions will be listed as blank names.
}
\description{
Retrieve names of recently changed pathways at WikiPathways.
}
\examples{
{
getRecentChangesNames('20180201000000')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCounts.R
\name{getCounts}
\alias{getCounts}
\title{Get Counts for WikiPathways Stats}
\usage{
getCounts()
}
\value{
A \code{data.frame} of counts
}
\description{
Retrieve information about various total counts at WikiPathways.
}
\examples{
{
getCounts()
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCurationStatus.R
\name{getCurationStatus}
\alias{getCurationStatus}
\title{Get Curation Status of a Pathway}
\usage{
getCurationStatus(pathway)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway, e.g. WP554}
}
\value{
A \code{data.frame} of status details
}
\description{
Retrieve information about curation status for a specific pathway.
}
\examples{
{
getCurationStatus('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCurationStatus.R
\name{getCurationTagNames}
\alias{getCurationTagNames}
\title{DEPRECATED: Get Curation Tag Names on a Pathway}
\usage{
getCurationTagNames(pathway)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, e.g. WP4}
}
\value{
A \code{list} of tag names
}
\description{
This function is provided for compatibility with older 
web services only and will be defunct at the next release.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getPathwayInfo.R
\name{getPathwayInfo}
\alias{getPathwayInfo}
\title{Get Pathway Info}
\usage{
getPathwayInfo(pathway)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, e.g. WP4}
}
\value{
A \code{dataframe} of pathway WPID, URL, name, species and latest revision
}
\description{
Retrieve information for a specific pathway
}
\examples{
{
getPathwayInfo('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByXref.R
\name{findPathwayNamesByXref}
\alias{findPathwayNamesByXref}
\title{Find Pathway Names By Xref}
\usage{
findPathwayNamesByXref(identifier, systemCode)
}
\arguments{
\item{identifier}{(\code{character}) The official ID specified by a data 
source or system}

\item{systemCode}{(\code{character}) The BridgeDb code associated with the 
data source or system, 
e.g., En (Ensembl), L (Entrez), Ch (HMDB), etc. See column two of 
https://github.com/bridgedb/datasources/blob/main/datasources.tsv.}
}
\value{
A \code{list} of lists
}
\description{
Retrieve list of pathway names containing the query Xref by 
identifier and system code.
}
\details{
Note: there will be multiple listings of the same pathway if the 
Xref is present mutiple times.
}
\examples{
{
findPathwayNamesByXref('ENSG00000232810','En')
}
}
\seealso{
findPathwaysByXref
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByLiterature.R
\name{findPathwayUrlsByLiterature}
\alias{findPathwayUrlsByLiterature}
\title{Find Pathway URLs By Literature}
\usage{
findPathwayUrlsByLiterature(query)
}
\arguments{
\item{query}{The \code{character} string to search for, e.g., a PMID, title 
keyword or author name.}
}
\value{
A \code{list} of lists
}
\description{
Retrieve list of pathway URLs containing the query citation.
}
\examples{
{
findPathwayUrlsByLiterature('19649250')
findPathwayUrlsByLiterature('smith')
findPathwayUrlsByLiterature('cancer')
}
}
\seealso{
findPathwaysByLiterature
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByOrcid.R
\name{findPathwayNamesByOrcid}
\alias{findPathwayNamesByOrcid}
\title{Find Pathway Names By ORCID}
\usage{
findPathwayNamesByOrcid(query = NULL)
}
\arguments{
\item{query}{The \code{character} ORCID to search for.}
}
\value{
A \code{list} of lists
}
\description{
Retrieve list of pathway names containing the query ORCID
}
\examples{
{
findPathwayNamesByOrcid(' 0000-0001-9773-4008')
}
}
\seealso{
findPathwaysByOrcid
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getOntologyTerms.R
\name{getOntologyTermIds}
\alias{getOntologyTermIds}
\title{Get Ontology Term IDs by Pathway}
\usage{
getOntologyTermIds(pathway)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, e.g. WP4}
}
\value{
A \code{list} of term identifiers
}
\description{
Retrieve identifiers of ontology terms for a specific pathway.
}
\examples{
{
getOntologyTermIds('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getCurationTags.R
\name{getCurationTags}
\alias{getCurationTags}
\title{Get Curation Tags on a Pathway}
\usage{
getCurationTags(pathway)
}
\arguments{
\item{pathway}{WikiPathways identifier (WPID) for the pathway to download, e.g. WP4}
}
\value{
A \code{list} of tag name, display name, revision, text, timestampe and user
}
\description{
Retrieve information about curation tags for a specific pathway.
}
\examples{
{
getCurationTags('WP554')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getOntologyTerms.R
\name{getPathwayIdsByParentOntologyTerm}
\alias{getPathwayIdsByParentOntologyTerm}
\title{Get Pathway WPIDs by Parent Ontology Term}
\usage{
getPathwayIdsByParentOntologyTerm(term)
}
\arguments{
\item{term}{(\code{character}) Official name of ontology term, e.g., "PW:0000045"}
}
\value{
A \code{list} of pathway WPIDs
}
\description{
Retrieve pathway WPIDs for every pathway with a child term of given ontology term
}
\examples{
{
getPathwayIdsByParentOntologyTerm('PW:0000045')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readGMT.R
\name{readGMTnames}
\alias{readGMTnames}
\title{Read GMT File for Names}
\usage{
readGMTnames(file)
}
\arguments{
\item{file}{Path to GMT file}
}
\value{
Data frame of term-namee associations
}
\description{
Reads any generic GMT file to produce a data frame of 
term-name associations useful in enrichment analyses and other 
applications.
}
\details{
The returned data frame includes only terms and names. If you want
another data frame with terms and genes, then see readGMT.
}
\examples{
\donttest{
#readGMTnames(system.file("extdata","my_gmt_file.gmt", package="rWikiPathways"))
#readGMTnames("path_to_your_gmt_file.gmt")
}
}
\seealso{
readGMT
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByLiterature.R
\name{findPathwayIdsByLiterature}
\alias{findPathwayIdsByLiterature}
\title{Find Pathway WPIDs By Literature}
\usage{
findPathwayIdsByLiterature(query)
}
\arguments{
\item{query}{The \code{character} string to search for, e.g., a PMID, title keyword or author name.}
}
\value{
A \code{list} of WPIDs
}
\description{
Retrieve list of pathway WPIDs containing the query citation.
}
\examples{
{
findPathwayIdsByLiterature('19649250')
findPathwayIdsByLiterature('smith')
findPathwayIdsByLiterature('cancer')
}
}
\seealso{
findPathwaysByLiterature
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByXref.R
\name{findPathwaysByXref}
\alias{findPathwaysByXref}
\title{Find Pathways By Xref}
\usage{
findPathwaysByXref(identifier = NULL, systemCode = NULL)
}
\arguments{
\item{identifier}{(\code{character}) The official ID specified by a data 
source or system}

\item{systemCode}{(\code{character}) The BridgeDb code associated with the 
data source or system, 
e.g., En (Ensembl), L (NCBI gene), H (HGNC), U (UniProt), Wd (Wikidata), 
Ce (ChEBI), Ik (InChI). See column two of 
https://github.com/bridgedb/datasources/blob/main/datasources.tsv.}
}
\value{
A \code{dataframe} of pathway attributes including the matching
identifiers
}
\description{
Retrieve pathways containing the query Xref by identifier
 and system code.
}
\examples{
{
findPathwaysByXref('ENSG00000100031','En')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByLiterature.R
\name{findPathwaysByLiterature}
\alias{findPathwaysByLiterature}
\title{Find Pathways By Literature}
\usage{
findPathwaysByLiterature(query = NULL)
}
\arguments{
\item{query}{The \code{character} string to search for, e.g., a PMID, title 
keyword, journal abbreviation, year, or author name.}
}
\value{
A \code{dataframe} of pathway attributes including the matching
citations
}
\description{
Retrieve pathways containing the query citation.
}
\examples{
{
findPathwaysByLiterature('15134803')
findPathwaysByLiterature('Schwartz GL')
findPathwaysByLiterature('Eur J Pharmacol')
findPathwaysByLiterature('antihypertensive drug responses')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/findPathwaysByOrcid.R
\name{findPathwayUrlsByOrcid}
\alias{findPathwayUrlsByOrcid}
\title{Find Pathway URLs By ORCID}
\usage{
findPathwayUrlsByOrcid(query = NULL)
}
\arguments{
\item{query}{The \code{character} ORCID to search for.}
}
\value{
A \code{list} of lists
}
\description{
Retrieve list of pathway URLs containing the query ORCID
}
\examples{
{
findPathwayUrlsByOrcid(' 0000-0001-9773-4008')
}
}
\seealso{
findPathwaysByOrcid
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getRecentChanges.R
\name{getRecentChangesIds}
\alias{getRecentChangesIds}
\title{Get WPIDs of Recent Changes}
\usage{
getRecentChangesIds(timestamp)
}
\arguments{
\item{timestamp}{(8 digits, YYYYMMDD) Limit by time, only pathways changed 
after the given date, e.g., 20180201 for changes since Feb 1st, 2018.}
}
\value{
A \code{list} of WPIDs
}
\description{
Retrieve WPIDs of recently changed pathways at WikiPathways.
}
\examples{
{
getRecentChangesIds('20180201')
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/listCommunities.R
\name{getPathwaysByCommunity}
\alias{getPathwaysByCommunity}
\title{Get Pathways By Community}
\usage{
getPathwaysByCommunity(community_tag = NULL)
}
\arguments{
\item{community_tag}{Abbreviated name of community}
}
\value{
A \code{data.frame} of pathway information
}
\description{
Retrieve pathways per community
}
\examples{
{
getPathwaysByCommunity("AOP")
}

}
